@@ -237,7 +237,11 @@ class ForecastDataDaily:
     @property
     def icon(self) -> str:
         """Condition Icon."""
-        return self._icon
+        if self._icon.find("cc-") > -1:
+            icon = self._icon[3:]
+        else:
+            icon = self._icon
+        return icon
 
     @property
     def sunrise(self) -> dt:
@@ -307,7 +311,11 @@ class ForecastDataDaily:
     @property
     def current_icon(self) -> str:
         """Current Condition Icon."""
-        return self._current_icon
+        if self._current_icon.find("cc-") > -1:
+            icon = self._current_icon[3:]
+        else:
+            icon = self._current_icon
+        return icon
 
     @property
     def temp_high_today(self) -> float:
@@ -366,7 +374,11 @@ class ForecastDataHourly:
     @property
     def icon(self) -> str:
         """Condition Icon."""
-        return self._icon
+        if self._icon.find("cc-") > -1:
+            icon = self._icon[3:]
+        else:
+            icon = self._icon
+        return icon
 
     @property
     def temperature(self) -> float:
@@ -456,7 +468,11 @@ class ForecastDataHourly:
     @property
     def current_icon(self) -> str:
         """Current Condition Icon."""
-        return self._current_icon
+        if self._current_icon.find("cc-") > -1:
+            icon = self._current_icon[3:]
+        else:
+            icon = self._current_icon
+        return icon
 
     @property
     def temp_high_today(self) -> float:
